========
musamusa
========
wordhord by suizokukan (suizokukan AT orange DOT fr)

Public repository of a private project. Copyrighted materials are not included.

Note : this Python3 project can't be used with python2.

project's purpose
=================
Toolbox to analyse Old English texts.

installation
============
$ pip3 install wordhord

more
====
see README.md file
see https://github.com/suizokukan/wordhord
